@@ -1,7 +1,4 @@
-# -*- coding: UTF-8 -*-
-
-
-"""Unittests for emoji.unicode_codes.versions"""
+"""Unittests for versions in EMOJI_DATA"""
 
 import emoji
 import pytest
@@ -53,21 +50,21 @@ def test_method_version():
     # Test method "emoji.version()"
 
     assert emoji.version(":snake:") == 0.6
-    assert emoji.version(u"\U0001F40D") == 0.6
+    assert emoji.version("\U0001F40D") == 0.6
 
     assert emoji.version(":brain:") == 5
-    assert emoji.version(u"\U0001F9E0") == 5
+    assert emoji.version("\U0001F9E0") == 5
     assert emoji.version(":cerebro:") == 5
 
     assert emoji.version("prefix :people_hugging: suffix") == 13
-    assert emoji.version(u"prefix \U0001FAC2 suffix") == 13
+    assert emoji.version("prefix \U0001FAC2 suffix") == 13
 
-    assert emoji.version(u"\U0001F611") == 1
+    assert emoji.version("\U0001F611") == 1
     assert emoji.version(":expressionless_face:") == 1
     assert emoji.version(":expressionless:") == 1
 
-    assert emoji.version("u':pouring_liquid::people_hugging:") == 14
-    assert emoji.version(u"\U0001FAD7\U0001FAC2") == 14
+    assert emoji.version("':pouring_liquid::people_hugging:") == 14
+    assert emoji.version("\U0001FAD7\U0001FAC2") == 14
 
     assert emoji.emojize(':123:', version=5, variant="text_type") == ':123:'
 
@@ -75,21 +72,23 @@ def test_method_version():
         emoji.version("test")
 
     with pytest.raises(ValueError):
-        emoji.version("u':snak:")
+        emoji.version("':snak:")
 
 
 def test_method_replace_version():
     # Test method "emoji.replace_emoji(string, version=X.Y)"
 
-    assert emoji.replace_emoji(u"\U0001F40D\U0001F9E0\U0001FAC2\U0001FAD7\U0001FAC2", version=6) == u"\U0001F40D\U0001F9E0"
+    assert emoji.replace_emoji("\U0001F40D\U0001F9E0\U0001FAC2\U0001FAD7\U0001FAC2", version=6) == "\U0001F40D\U0001F9E0"
 
-    assert emoji.replace_emoji(u'Hi, I am fine. 😁', version=0) == u'Hi, I am fine. '
-    assert emoji.replace_emoji(u'Hi', version=0) == u'Hi'
-    assert emoji.replace_emoji(u'Hello 🇫🇷👌', version=0) == u'Hello '
-    assert emoji.replace_emoji(u'Hello 🇫🇷👌', u'x', version=0,) == u'Hello xx'
-    assert emoji.replace_emoji(u'Hello 🇫🇷👌', u'x', version=1,) == u'Hello 🇫🇷👌'
+    assert emoji.replace_emoji('Hi, I am fine. 😁', version=0) == 'Hi, I am fine. '
+    assert emoji.replace_emoji('Hi', version=0) == 'Hi'
+    assert emoji.replace_emoji('Hello 🇫🇷👌', version=0) == 'Hello '
+    assert emoji.replace_emoji('Hello 🇫🇷👌', 'x', version=0,) == 'Hello xx'
+    assert emoji.replace_emoji('Hello 🇫🇷👌', 'x', version=1,) == 'Hello 🇫🇷👌'
 
     def replace(emj, data):
-        assert emj in [u"🇫🇷", u"👌"]
-        return u'x'
-    assert emoji.replace_emoji(u'Hello 🇫🇷👌', replace, version=0.1) == u'Hello xx'
+        assert emj in ["🇫🇷", "👌"]
+        return 'x'
+    assert emoji.replace_emoji('Hello 🇫🇷👌', replace, version=0.1) == 'Hello xx'
+
+    assert emoji.replace_emoji('A 🦖 is eating a 🥐', replace='', version=5.0) == 'A 🦖 is eating a 🥐'
